Reference
=========

Preferences
-----------

.. toctree::
   :maxdepth: 3

   preferences/profile
   preferences/profile_from_file
   preferences/generator_profile_cubic_uniform
   preferences/generator_profile_euclidean_box
   preferences/generator_profile_gaussian_well
   preferences/generator_profile_ladder
   preferences/generator_profile_spheroid
   preferences/generator_profile_vmf_hypercircle
   preferences/generator_profile_vmf_hypersphere

Voting rules
------------

.. toctree::
   :maxdepth: 3

   rules/rule
   rules/rule_approval
   rules/rule_baldwin
   rules/rule_black
   rules/rule_borda
   rules/rule_bucklin
   rules/rule_condorcet_abs_irv
   rules/rule_condorcet_sum_defeats
   rules/rule_condorcet_vtb_irv
   rules/rule_coombs
   rules/rule_copeland
   rules/rule_exhaustive_ballot
   rules/rule_icrv
   rules/rule_irv
   rules/rule_irv_average
   rules/rule_irv_duels
   rules/rule_iterated_bucklin
   rules/rule_kemeny
   rules/rule_kim_roush
   rules/rule_majority_judgment
   rules/rule_maximin
   rules/rule_nanson
   rules/rule_plurality
   rules/rule_range_voting
   rules/rule_ranked_pairs
   rules/rule_schulze
   rules/rule_smith_irv
   rules/rule_split_cycle
   rules/rule_star
   rules/rule_tideman
   rules/rule_two_round
   rules/rule_veto
   rules/rule_woodall
